@@ -1,7 +1,10 @@
+package Couchbase::Core;
+use strict;
+use warnings;
 our $VERSION;
 BEGIN {
     require XSLoader;
-    $VERSION = '2.0.0_4';
+    $VERSION = '2.0.1';
     XSLoader::load('Couchbase', $VERSION);
 }
 
