@@ -195,13 +195,13 @@ load_doc_options(PLCB_t *parent, AV *ret, plcb_OPTION *values)
             continue;
         }
 
-        if (cur->key == PLCB_ARG_K_CAS) {
+        if (!strcmp(cur->key, PLCB_ARG_K_CAS)) {
             ix = PLCB_RETIDX_CAS;
-        } else if (cur->key == PLCB_ARG_K_EXPIRY) {
+        } else if (!strcmp(cur->key,PLCB_ARG_K_EXPIRY)) {
             ix = PLCB_RETIDX_EXP;
-        } else if (cur->key == PLCB_ARG_K_VALUE) {
+        } else if (!strcmp(cur->key,PLCB_ARG_K_VALUE)) {
             ix = PLCB_RETIDX_VALUE;
-        } else if (cur->key == PLCB_ARG_K_FMT) {
+        } else if (!strcmp(cur->key,PLCB_ARG_K_FMT)) {
             ix = PLCB_RETIDX_FMTSPEC;
         } else {
             continue;
@@ -305,7 +305,7 @@ PLCB_args_unlock(PLCB_t *object, plcb_SINGLEOP *args, lcb_CMDUNLOCK *ucmd)
     };
 
     load_doc_options(object, args->docav, argspecs);
-    if (!ucmd->cas) {
+    if (ucmd->cas == 0 && args->cmdbase == PLCB_CMD_UNLOCK) {
         die("Unlock command must have CAS");
     }
     return 0;
@@ -371,6 +371,13 @@ PLCB_args_set(PLCB_t *object, plcb_SINGLEOP *args, lcb_CMDSTORE *scmd, plcb_DOCV
         scmd->cas = 0;
     }
 
+    if (is_append(args->cmdbase)) {
+        scmd->exptime = 0;
+        scmd->flags = 0;
+    } else if (args->cmdbase == PLCB_CMD_ADD) {
+        scmd->cas = 0;
+    }
+
     dur_sv = *av_fetch(args->docav, PLCB_RETIDX_OPTIONS, 1);
     if (SvIOK(dur_sv)) {
         SvUVX(dur_sv) = PLCB_MKDURABILITY(persist_to, replicate_to);
